@@ -16,6 +16,8 @@ HEADERS = {
 
 DEPOT_ROOT_ENV_VAR = "ASWAN_DEPOT_ROOT"
 DEFAULT_REMOTE_ENV_VAR = "ASWAN_REMOTE"
+HEX_ENV = "ASWAN_AUTH_HEX"
+PW_ENV = "ASWAN_AUTH_PASS"
 DEFAULT_DEPOT_ROOT = Path.home() / "aswan-depots"
 CONFIG_PATH = Path.home() / ".config" / "aswan"
 
